abacusai.database_connector — AbacusAI documentation

# `abacusai.database_connector`

## Module Contents

### Classes

`DatabaseConnector` | A connector to an external service

class abacusai.database_connector.DatabaseConnector(client, databaseConnectorId=None, service=None, name=None, status=None, auth=None, createdAt=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A connector to an external service

  Parameters

    - client (ApiClient) – An authenticated API Client instance

    - databaseConnectorId (str) – The unique ID for the connection.

    - service (str) – The service this connection connects to

    - name (str) – A user-friendly name for the service

    - status (str) – The status of the Database Connector

    - auth (dict) – Non-secret connection information for this connector

    - createdAt (str) – When the API key was created

  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns

      The dict value representation of the class parameters

    Return type

      dict

  list_objects()

    Lists querable objects in the database connector.

    Parameters

      database_connector_id (str) – The unique identifier for the database connector.

  get_object_schema(object_name=None)

    Get the schema of an object in an database connector.

    Parameters

      object_name (str) – The unique identifier for the object in the external system.

  rename(name)

    Renames a Database Connector

    Parameters

      name (str) – The new name for the Database Connector

  verify()

    Checks to see if Abacus.AI can access the database.

    Parameters

      database_connector_id (str) – The unique identifier for the database connector.

  delete()

    Delete a database connector.

    Parameters

      database_connector_id (str) – The unique identifier for the database connector.